@@ -9,17 +9,18 @@ pub mod ecdh;
 pub mod hash;
 pub mod symmetric;
 
+/// Returns a short, human-readable description of the backend.
+pub fn backend() -> String {
+    // XXX: can we include features and the version?
+    "RustCrypto".to_string()
+}
+
 /// Fills the given buffer with random data.
-///
-/// Fills the given buffer with random data produced by a
-/// cryptographically secure pseudorandom number generator (CSPRNG).
-/// The output may be used as session keys or to derive long-term
-/// cryptographic keys from.
-pub fn random<B: AsMut<[u8]>>(mut buf: B) {
+pub fn random(buf: &mut [u8]) {
     use rand07::rngs::OsRng;
     use rand07::RngCore;
 
-    OsRng.fill_bytes(buf.as_mut())
+    OsRng.fill_bytes(buf)
 }
 
 impl PublicKeyAlgorithm {
