@@ -213,7 +213,7 @@ impl fmt::Debug for Protected {
 #[derive(Clone, Debug)]
 pub struct Encrypted {
     ciphertext: Protected,
-    iv: Protected,
+    salt: [u8; 32],
 }
 assert_send_and_sync!(Encrypted);
 
@@ -243,7 +243,8 @@ const ENCRYPTED_MEMORY_PAGE_SIZE: usize = 4096;
 ///
 /// Code outside of it cannot access it, because `PREKEY` is private.
 mod has_access_to_prekey {
-    use std::io::{self, Cursor, Write};
+    use std::io::{self, Write};
+    use buffered_reader::Memory;
     use crate::types::{AEADAlgorithm, HashAlgorithm, SymmetricAlgorithm};
     use crate::crypto::{aead, SessionKey};
     use crate::crypto::hash::Digest;
@@ -272,9 +273,10 @@ mod has_access_to_prekey {
 
     impl Encrypted {
         /// Computes the sealing key used to encrypt the memory.
-        fn sealing_key() -> SessionKey {
+        fn sealing_key(salt: &[u8; 32]) -> SessionKey {
             let mut ctx = HASH_ALGO.context()
                 .expect("Mandatory algorithm unsupported");
+            ctx.update(salt);
             PREKEY.iter().for_each(|page| ctx.update(page));
             let mut sk: SessionKey = vec![0; 256/8].into();
             let _ = ctx.digest(&mut sk);
@@ -283,20 +285,16 @@ mod has_access_to_prekey {
 
         /// Encrypts the given chunk of memory.
         pub fn new(p: Protected) -> Self {
-            let mut iv =
-                vec![0; AEAD_ALGO.iv_size()
-                            .expect("Mandatory algorithm unsupported")];
-            crate::crypto::random(&mut iv);
-
+            let mut salt = [0; 32];
+            crate::crypto::random(&mut salt);
             let mut ciphertext = Vec::new();
             {
                 let mut encryptor =
-                    aead::Encryptor::new(1,
-                                         SYMMETRIC_ALGO,
+                    aead::Encryptor::new(SYMMETRIC_ALGO,
                                          AEAD_ALGO,
                                          4096,
-                                         &iv,
-                                         &Self::sealing_key(),
+                                         CounterSchedule::default(),
+                                         Self::sealing_key(&salt),
                                          &mut ciphertext)
                     .expect("Mandatory algorithm unsupported");
                 encryptor.write_all(&p).unwrap();
@@ -305,7 +303,7 @@ mod has_access_to_prekey {
 
             Encrypted {
                 ciphertext: ciphertext.into(),
-                iv: iv.into(),
+                salt,
             }
         }
 
@@ -314,15 +312,18 @@ mod has_access_to_prekey {
         pub fn map<F, T>(&self, mut fun: F) -> T
             where F: FnMut(&Protected) -> T
         {
+            let ciphertext =
+                Memory::with_cookie(&self.ciphertext, Default::default());
             let mut plaintext = Vec::new();
+
             let mut decryptor =
-                aead::Decryptor::new(1,
+                aead::Decryptor::from_buffered_reader(
                                      SYMMETRIC_ALGO,
                                      AEAD_ALGO,
                                      4096,
-                                     &self.iv,
-                                     &Self::sealing_key(),
-                                     Cursor::new(&self.ciphertext))
+                                     CounterSchedule::default(),
+                                     Self::sealing_key(&self.salt),
+                                     Box::new(ciphertext))
                 .expect("Mandatory algorithm unsupported");
             io::copy(&mut decryptor, &mut plaintext)
                 .expect("Encrypted memory modified or corrupted");
@@ -330,6 +331,47 @@ mod has_access_to_prekey {
             fun(&plaintext)
         }
     }
+
+    #[derive(Default)]
+    struct CounterSchedule {}
+
+    impl aead::Schedule for CounterSchedule {
+        fn next_chunk<F, R>(&self, index: u64, mut fun: F) -> R
+        where
+            F: FnMut(&[u8], &[u8]) -> R,
+        {
+            // The nonce is a simple counter.
+            let mut nonce_store = [0u8; aead::MAX_NONCE_LEN];
+            let nonce_len = AEAD_ALGO.nonce_size()
+                .expect("Mandatory algorithm unsupported");
+            assert!(nonce_len >= 8);
+            let nonce = &mut nonce_store[..nonce_len];
+            let index_be: [u8; 8] = index.to_be_bytes();
+            nonce[nonce_len - 8..].copy_from_slice(&index_be);
+
+            // No AAD.
+            fun(nonce, &[])
+        }
+
+        fn final_chunk<F, R>(&self, index: u64, length: u64, mut fun: F) -> R
+        where
+            F: FnMut(&[u8], &[u8]) -> R
+        {
+            // The nonce is a simple counter.
+            let mut nonce_store = [0u8; aead::MAX_NONCE_LEN];
+            let nonce_len = AEAD_ALGO.nonce_size()
+                .expect("Mandatory algorithm unsupported");
+            assert!(nonce_len >= 8);
+            let nonce = &mut nonce_store[..nonce_len];
+            let index_be: [u8; 8] = index.to_be_bytes();
+            nonce[nonce_len - 8..].copy_from_slice(&index_be);
+
+            // Plaintext bytes as AAD to prevent truncation.
+            let aad: [u8; 8] = length.to_be_bytes();
+
+            fun(nonce, &aad)
+        }
+    }
 }
 
 /// Time-constant comparison.
