@@ -173,6 +173,9 @@ use crate::crypto::{
     Password,
 };
 
+mod any;
+pub use self::any::Any;
+
 mod tag;
 pub use self::tag::Tag;
 pub mod header;
@@ -365,6 +368,34 @@ impl Packet {
         }
     }
 
+    /// Returns the `Packet's` version, if the packet is versioned and
+    /// recognized.
+    ///
+    /// If the packet is not versioned, or we couldn't parse the
+    /// packet, this function returns `None`.
+    pub fn version(&self) -> Option<u8> {
+        match self {
+            Packet::Unknown(_) => None,
+            Packet::Signature(p) => Some(p.version()),
+            Packet::OnePassSig(p) => Some(p.version()),
+            Packet::PublicKey(p) => Some(p.version()),
+            Packet::PublicSubkey(p) => Some(p.version()),
+            Packet::SecretKey(p) => Some(p.version()),
+            Packet::SecretSubkey(p) => Some(p.version()),
+            Packet::Marker(_) => None,
+            Packet::Trust(_) => None,
+            Packet::UserID(_) => None,
+            Packet::UserAttribute(_) => None,
+            Packet::Literal(_) => None,
+            Packet::CompressedData(_) => None,
+            Packet::PKESK(p) => Some(p.version()),
+            Packet::SKESK(p) => Some(p.version()),
+            Packet::SEIP(p) => Some(p.version()),
+            Packet::MDC(_) => None,
+            Packet::AED(p) => Some(p.version()),
+        }
+    }
+
     /// Hashes most everything into state.
     ///
     /// This is an alternate implementation of [`Hash`], which does
@@ -2010,4 +2041,19 @@ mod test {
             }
         }
     }
+
+    /// Problem on systems with 32-bit time_t.
+    #[test]
+    fn issue_802() -> Result<()> {
+        let pp = crate::PacketPile::from_bytes(b"-----BEGIN PGP ARMORED FILE-----
+
+xiEE/////xIJKyQDAwIIAQENAFYp8M2JngCfc04tIwMBCuU=
+-----END PGP ARMORED FILE-----
+")?;
+        let p = pp.path_ref(&[0]).unwrap();
+        let buf = p.to_vec().expect("Failed to serialize packet");
+        let q = Packet::from_bytes(&buf).unwrap();
+        assert_eq!(p, &q);
+        Ok(())
+    }
 }
