@@ -272,15 +272,7 @@ impl SKESK4 {
             Ok((sym, plain[1..].into()))
         } else {
             // No ESK, we return the derived key.
-
-            #[allow(deprecated)]
-            match self.s2k {
-                S2K::Simple{ .. } =>
-                    Err(Error::InvalidOperation(
-                        "SKESK4: Cannot use Simple S2K without ESK".into())
-                        .into()),
-                _ => Ok((self.sym_algo, key)),
-            }
+            Ok((self.sym_algo, key))
         }
     }
 }
@@ -464,7 +456,7 @@ impl SKESK5 {
 
         // Derive key and make a cipher.
         let key = s2k.derive_key(password, esk_algo.key_size()?)?;
-        let mut iv = vec![0u8; esk_aead.iv_size()?];
+        let mut iv = vec![0u8; esk_aead.nonce_size()?];
         crypto::random(&mut iv);
         let mut ctx = esk_aead.context(esk_algo, &key, &iv, CipherOp::Encrypt)?;
 
@@ -581,7 +573,7 @@ impl From<SKESK5> for Packet {
 impl Arbitrary for SKESK5 {
     fn arbitrary(g: &mut Gen) -> Self {
         let algo = AEADAlgorithm::EAX;  // The only one we dig.
-        let mut iv = vec![0u8; algo.iv_size().unwrap()];
+        let mut iv = vec![0u8; algo.nonce_size().unwrap()];
         for b in iv.iter_mut() {
             *b = u8::arbitrary(g);
         }
@@ -658,4 +650,61 @@ mod test {
         packets[0].serialize(&mut serialized).unwrap();
         assert_eq!(&raw[..], &serialized[..]);
     }
+
+    /// Tests various S2K methods, with and without encrypted session
+    /// key.
+    #[test]
+    fn skesk4_s2k_variants() -> Result<()> {
+        use std::io::Read;
+        use crate::{
+            Cert,
+            Fingerprint,
+            packet::{SKESK, PKESK},
+            parse::stream::*,
+        };
+
+        struct H();
+        impl VerificationHelper for H {
+            fn get_certs(&mut self, _ids: &[crate::KeyHandle])
+                         -> Result<Vec<Cert>> {
+                Ok(Vec::new())
+            }
+
+            fn check(&mut self, _m: MessageStructure)
+                     -> Result<()> {
+                Ok(())
+            }
+        }
+
+        impl DecryptionHelper for H {
+            fn decrypt<D>(&mut self, _: &[PKESK], skesks: &[SKESK],
+                          _: Option<SymmetricAlgorithm>,
+                          mut decrypt: D) -> Result<Option<Fingerprint>>
+            where D: FnMut(SymmetricAlgorithm, &SessionKey) -> bool
+            {
+                assert_eq!(skesks.len(), 1);
+                let (cipher, sk) = skesks[0].decrypt(&"password".into())?;
+                assert_eq!(cipher, SymmetricAlgorithm::AES256);
+                let r = decrypt(cipher, &sk);
+                assert!(r);
+                Ok(None)
+            }
+        }
+
+        let p = &crate::policy::StandardPolicy::new();
+        for variant in &["simple", "salted", "iterated.min", "iterated.max"] {
+            for esk in &["", ".esk"] {
+                let name = format!("s2k/{}{}.pgp", variant, esk);
+                eprintln!("{}", name);
+                let mut verifier = DecryptorBuilder::from_bytes(
+                    crate::tests::message(&name))?
+                    .with_policy(p, None, H())?;
+                let mut b = Vec::new();
+                verifier.read_to_end(&mut b)?;
+                assert_eq!(&b, b"Hello World :)");
+            }
+        }
+
+        Ok(())
+    }
 }
