@@ -239,24 +239,60 @@ impl From<PublicKeyAlgorithm> for u8 {
     }
 }
 
+/// Formats the public key algorithm name.
+///
+/// There are two ways the public key algorithm name can be formatted.
+/// By default the short name is used.  The alternate format uses the
+/// full public key algorithm name.
+///
+/// # Examples
+///
+/// ```
+/// use sequoia_openpgp as openpgp;
+/// use openpgp::types::PublicKeyAlgorithm;
+///
+/// // default, short format
+/// assert_eq!("ECDH", format!("{}", PublicKeyAlgorithm::ECDH));
+///
+/// // alternate, long format
+/// assert_eq!("ECDH public key algorithm", format!("{:#}", PublicKeyAlgorithm::ECDH));
+/// ```
 impl fmt::Display for PublicKeyAlgorithm {
+    #[allow(deprecated)]
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         use crate::PublicKeyAlgorithm::*;
-        #[allow(deprecated)]
-        match *self {
-            RSAEncryptSign => f.write_str("RSA (Encrypt or Sign)"),
-            RSAEncrypt => f.write_str("RSA Encrypt-Only"),
-            RSASign => f.write_str("RSA Sign-Only"),
-            ElGamalEncrypt => f.write_str("ElGamal (Encrypt-Only)"),
-            DSA => f.write_str("DSA (Digital Signature Algorithm)"),
-            ECDSA => f.write_str("ECDSA public key algorithm"),
-            ElGamalEncryptSign => f.write_str("ElGamal (Encrypt or Sign)"),
-            ECDH => f.write_str("ECDH public key algorithm"),
-            EdDSA => f.write_str("EdDSA Edwards-curve Digital Signature Algorithm"),
-            Private(u) =>
-                f.write_fmt(format_args!("Private/Experimental public key algorithm {}", u)),
-            Unknown(u) =>
-                f.write_fmt(format_args!("Unknown public key algorithm {}", u)),
+        if f.alternate() {
+            match *self {
+                RSAEncryptSign => f.write_str("RSA (Encrypt or Sign)"),
+                RSAEncrypt => f.write_str("RSA Encrypt-Only"),
+                RSASign => f.write_str("RSA Sign-Only"),
+                ElGamalEncrypt => f.write_str("ElGamal (Encrypt-Only)"),
+                DSA => f.write_str("DSA (Digital Signature Algorithm)"),
+                ECDSA => f.write_str("ECDSA public key algorithm"),
+                ElGamalEncryptSign => f.write_str("ElGamal (Encrypt or Sign)"),
+                ECDH => f.write_str("ECDH public key algorithm"),
+                EdDSA => f.write_str("EdDSA Edwards-curve Digital Signature Algorithm"),
+                Private(u) =>
+                    f.write_fmt(format_args!("Private/Experimental public key algorithm {}", u)),
+                Unknown(u) =>
+                    f.write_fmt(format_args!("Unknown public key algorithm {}", u)),
+            }
+        } else {
+            match *self {
+                RSAEncryptSign => f.write_str("RSA"),
+                RSAEncrypt => f.write_str("RSA"),
+                RSASign => f.write_str("RSA"),
+                ElGamalEncrypt => f.write_str("ElGamal"),
+                DSA => f.write_str("DSA"),
+                ECDSA => f.write_str("ECDSA"),
+                ElGamalEncryptSign => f.write_str("ElGamal"),
+                ECDH => f.write_str("ECDH"),
+                EdDSA => f.write_str("EdDSA"),
+                Private(u) =>
+                    f.write_fmt(format_args!("Private algo {}", u)),
+                Unknown(u) =>
+                    f.write_fmt(format_args!("Unknown algo {}", u)),
+            }
         }
     }
 }
@@ -371,21 +407,55 @@ impl Curve {
     }
 }
 
+/// Formats the elliptic curve name.
+///
+/// There are two ways the elliptic curve name can be formatted.  By
+/// default the short name is used.  The alternate format uses the
+/// full curve name.
+///
+/// # Examples
+///
+/// ```
+/// use sequoia_openpgp as openpgp;
+/// use openpgp::types::Curve;
+///
+/// // default, short format
+/// assert_eq!("NIST P-256", format!("{}", Curve::NistP256));
+///
+/// // alternate, long format
+/// assert_eq!("NIST curve P-256", format!("{:#}", Curve::NistP256));
+/// ```
 impl fmt::Display for Curve {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         use self::Curve::*;
-        match *self {
-            NistP256 => f.write_str("NIST curve P-256"),
-            NistP384 => f.write_str("NIST curve P-384"),
-            NistP521 => f.write_str("NIST curve P-521"),
-            BrainpoolP256 => f.write_str("brainpoolP256r1"),
-            BrainpoolP512 => f.write_str("brainpoolP512r1"),
-            Ed25519
-                => f.write_str("D.J. Bernstein's \"Twisted\" Edwards curve Ed25519"),
-            Cv25519
-                => f.write_str("Elliptic curve Diffie-Hellman using D.J. Bernstein's Curve25519"),
-            Unknown(ref oid)
-             => write!(f, "Unknown curve (OID: {:?})", oid),
+        if f.alternate() {
+            match *self {
+                NistP256 => f.write_str("NIST curve P-256"),
+                NistP384 => f.write_str("NIST curve P-384"),
+                NistP521 => f.write_str("NIST curve P-521"),
+                BrainpoolP256 => f.write_str("brainpoolP256r1"),
+                BrainpoolP512 => f.write_str("brainpoolP512r1"),
+                Ed25519
+                    => f.write_str("D.J. Bernstein's \"Twisted\" Edwards curve Ed25519"),
+                Cv25519
+                    => f.write_str("Elliptic curve Diffie-Hellman using D.J. Bernstein's Curve25519"),
+                Unknown(ref oid)
+                    => write!(f, "Unknown curve (OID: {:?})", oid),
+            }
+        } else {
+            match *self {
+                NistP256 => f.write_str("NIST P-256"),
+                NistP384 => f.write_str("NIST P-384"),
+                NistP521 => f.write_str("NIST P-521"),
+                BrainpoolP256 => f.write_str("brainpoolP256r1"),
+                BrainpoolP512 => f.write_str("brainpoolP512r1"),
+                Ed25519
+                    => f.write_str("Ed25519"),
+                Cv25519
+                    => f.write_str("Curve25519"),
+                Unknown(ref oid)
+                    => write!(f, "Unknown curve {:?}", oid),
+            }
         }
     }
 }
@@ -636,37 +706,89 @@ impl From<SymmetricAlgorithm> for u8 {
     }
 }
 
+
+/// Formats the symmetric algorithm name.
+///
+/// There are two ways the symmetric algorithm name can be formatted.
+/// By default the short name is used.  The alternate format uses the
+/// full algorithm name.
+///
+/// # Examples
+///
+/// ```
+/// use sequoia_openpgp as openpgp;
+/// use openpgp::types::SymmetricAlgorithm;
+///
+/// // default, short format
+/// assert_eq!("AES-128", format!("{}", SymmetricAlgorithm::AES128));
+///
+/// // alternate, long format
+/// assert_eq!("AES with 128-bit key", format!("{:#}", SymmetricAlgorithm::AES128));
+/// ```
 impl fmt::Display for SymmetricAlgorithm {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        match *self {
-            SymmetricAlgorithm::Unencrypted =>
-                f.write_str("Unencrypted"),
-            SymmetricAlgorithm::IDEA =>
-                f.write_str("IDEA"),
-            SymmetricAlgorithm::TripleDES =>
-                f.write_str("TripleDES (EDE-DES, 168 bit key derived from 192))"),
-            SymmetricAlgorithm::CAST5 =>
-                f.write_str("CAST5 (128 bit key, 16 rounds)"),
-            SymmetricAlgorithm::Blowfish =>
-                f.write_str("Blowfish (128 bit key, 16 rounds)"),
-            SymmetricAlgorithm::AES128 =>
-                f.write_str("AES with 128-bit key"),
-            SymmetricAlgorithm::AES192 =>
-                f.write_str("AES with 192-bit key"),
-            SymmetricAlgorithm::AES256 =>
-                f.write_str("AES with 256-bit key"),
-            SymmetricAlgorithm::Twofish =>
-                f.write_str("Twofish with 256-bit key"),
-            SymmetricAlgorithm::Camellia128 =>
-                f.write_str("Camellia with 128-bit key"),
-            SymmetricAlgorithm::Camellia192 =>
-                f.write_str("Camellia with 192-bit key"),
-            SymmetricAlgorithm::Camellia256 =>
-                f.write_str("Camellia with 256-bit key"),
-            SymmetricAlgorithm::Private(u) =>
-                f.write_fmt(format_args!("Private/Experimental symmetric key algorithm {}", u)),
-            SymmetricAlgorithm::Unknown(u) =>
-                f.write_fmt(format_args!("Unknown symmetric key algorithm {}", u)),
+        if f.alternate() {
+            match *self {
+                SymmetricAlgorithm::Unencrypted =>
+                    f.write_str("Unencrypted"),
+                SymmetricAlgorithm::IDEA =>
+                    f.write_str("IDEA"),
+                SymmetricAlgorithm::TripleDES =>
+                    f.write_str("TripleDES (EDE-DES, 168 bit key derived from 192))"),
+                SymmetricAlgorithm::CAST5 =>
+                    f.write_str("CAST5 (128 bit key, 16 rounds)"),
+                SymmetricAlgorithm::Blowfish =>
+                    f.write_str("Blowfish (128 bit key, 16 rounds)"),
+                SymmetricAlgorithm::AES128 =>
+                    f.write_str("AES with 128-bit key"),
+                SymmetricAlgorithm::AES192 =>
+                    f.write_str("AES with 192-bit key"),
+                SymmetricAlgorithm::AES256 =>
+                    f.write_str("AES with 256-bit key"),
+                SymmetricAlgorithm::Twofish =>
+                    f.write_str("Twofish with 256-bit key"),
+                SymmetricAlgorithm::Camellia128 =>
+                    f.write_str("Camellia with 128-bit key"),
+                SymmetricAlgorithm::Camellia192 =>
+                    f.write_str("Camellia with 192-bit key"),
+                SymmetricAlgorithm::Camellia256 =>
+                    f.write_str("Camellia with 256-bit key"),
+                SymmetricAlgorithm::Private(u) =>
+                    f.write_fmt(format_args!("Private/Experimental symmetric key algorithm {}", u)),
+                SymmetricAlgorithm::Unknown(u) =>
+                    f.write_fmt(format_args!("Unknown symmetric key algorithm {}", u)),
+            }
+        } else {
+            match *self {
+                SymmetricAlgorithm::Unencrypted =>
+                    f.write_str("Unencrypted"),
+                SymmetricAlgorithm::IDEA =>
+                    f.write_str("IDEA"),
+                SymmetricAlgorithm::TripleDES =>
+                    f.write_str("3DES"),
+                SymmetricAlgorithm::CAST5 =>
+                    f.write_str("CAST5"),
+                SymmetricAlgorithm::Blowfish =>
+                    f.write_str("Blowfish"),
+                SymmetricAlgorithm::AES128 =>
+                    f.write_str("AES-128"),
+                SymmetricAlgorithm::AES192 =>
+                    f.write_str("AES-192"),
+                SymmetricAlgorithm::AES256 =>
+                    f.write_str("AES-256"),
+                SymmetricAlgorithm::Twofish =>
+                    f.write_str("Twofish"),
+                SymmetricAlgorithm::Camellia128 =>
+                    f.write_str("Camellia-128"),
+                SymmetricAlgorithm::Camellia192 =>
+                    f.write_str("Camellia-192"),
+                SymmetricAlgorithm::Camellia256 =>
+                    f.write_str("Camellia-256"),
+                SymmetricAlgorithm::Private(u) =>
+                    f.write_fmt(format_args!("Private symmetric key algo {}", u)),
+                SymmetricAlgorithm::Unknown(u) =>
+                    f.write_fmt(format_args!("Unknown symmetric key algo {}", u)),
+            }
         }
     }
 }
@@ -763,17 +885,48 @@ impl From<AEADAlgorithm> for u8 {
     }
 }
 
+/// Formats the AEAD algorithm name.
+///
+/// There are two ways the AEAD algorithm name can be formatted.  By
+/// default the short name is used.  The alternate format uses the
+/// full algorithm name.
+///
+/// # Examples
+///
+/// ```
+/// use sequoia_openpgp as openpgp;
+/// use openpgp::types::AEADAlgorithm;
+///
+/// // default, short format
+/// assert_eq!("EAX", format!("{}", AEADAlgorithm::EAX));
+///
+/// // alternate, long format
+/// assert_eq!("EAX mode", format!("{:#}", AEADAlgorithm::EAX));
+/// ```
 impl fmt::Display for AEADAlgorithm {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        match *self {
-            AEADAlgorithm::EAX =>
-                f.write_str("EAX mode"),
-            AEADAlgorithm::OCB =>
-                f.write_str("OCB mode"),
-            AEADAlgorithm::Private(u) =>
-                f.write_fmt(format_args!("Private/Experimental AEAD algorithm {}", u)),
-            AEADAlgorithm::Unknown(u) =>
-                f.write_fmt(format_args!("Unknown AEAD algorithm {}", u)),
+        if f.alternate() {
+            match *self {
+                AEADAlgorithm::EAX =>
+                    f.write_str("EAX mode"),
+                AEADAlgorithm::OCB =>
+                    f.write_str("OCB mode"),
+                AEADAlgorithm::Private(u) =>
+                    f.write_fmt(format_args!("Private/Experimental AEAD algorithm {}", u)),
+                AEADAlgorithm::Unknown(u) =>
+                    f.write_fmt(format_args!("Unknown AEAD algorithm {}", u)),
+            }
+        } else {
+            match *self {
+                AEADAlgorithm::EAX =>
+                    f.write_str("EAX"),
+                AEADAlgorithm::OCB =>
+                    f.write_str("OCB"),
+                AEADAlgorithm::Private(u) =>
+                    f.write_fmt(format_args!("Private AEAD algo {}", u)),
+                AEADAlgorithm::Unknown(u) =>
+                    f.write_fmt(format_args!("Unknown AEAD algo {}", u)),
+            }
         }
     }
 }
@@ -1581,6 +1734,7 @@ pub enum DataFormat {
     /// This is defined in [Section 5.10 of RFC4880bis].
     ///
     ///   [Section 5.10 of RFC4880bis]: https://tools.ietf.org/html/draft-ietf-openpgp-rfc4880bis-05#section-5.10
+    #[deprecated(since = "1.10.0", note = "Do not use as semantics are unclear")]
     MIME,
 
     /// Unknown format specifier.
@@ -1607,6 +1761,7 @@ impl From<char> for DataFormat {
             'b' => Binary,
             't' => Text,
             'u' => Unicode,
+            #[allow(deprecated)]
             'm' => MIME,
             c => Unknown(c),
         }
@@ -1626,6 +1781,7 @@ impl From<DataFormat> for char {
             Binary => 'b',
             Text => 't',
             Unicode => 'u',
+            #[allow(deprecated)]
             MIME => 'm',
             Unknown(c) => c,
         }
@@ -1642,6 +1798,7 @@ impl fmt::Display for DataFormat {
                 f.write_str("Text data"),
             Unicode =>
                 f.write_str("Text data (UTF-8)"),
+            #[allow(deprecated)]
             MIME =>
                 f.write_str("MIME message body part"),
             Unknown(c) =>
